fedstatAPIr-package: fedstatAPIr: Unofficial API for Fedstat (Rosstat EMISS...

fedstatAPIr-packageR Documentation

fedstatAPIr: Unofficial API for Fedstat (Rosstat EMISS System) for Automatic and Efficient Data Queries

Description

An API for automatic data queries to the fedstat https://www.fedstat.ru, using a small set of functions with a common interface.

An API for automatic data queries to the fedstat https://www.fedstat.ru, using a small set of functions with a common interface.

Author(s)

Maintainer: Denis Krylov deniskrylovvit@gmail.com

Authors:

See Also

Useful links:


fedstatAPIr documentation built on Sept. 4, 2026, 9:07 a.m.