fedstat_indicators_names_database: Database of all indicator names presented on the fedstat.ru...

fedstat_indicators_names_databaseR Documentation

Database of all indicator names presented on the fedstat.ru with hierarchical grouping

Description

Allows researchers to search for interesting indicators more easily. The database can be refreshed by the user via fedstat_indicator_info().

Usage

fedstat_indicators_names_database

Format

A data frame with the following variables:

department

the name of the department from which the data comes

group

thematic grouping of the indicator

id

indicator id (used in URL and API calls)

title

indicator name/title

hidden

boolean, TRUE if indicator is hidden on the website

Details

The version shipped with the package was last refreshed on 2026-09-04.

https://fedstat.ru/organizations/


fedstatAPIr documentation built on Sept. 4, 2026, 9:07 a.m.