| fedstatAPIr-package | R Documentation |
An API for automatic data queries to the fedstat https://www.fedstat.ru, using a small set of functions with a common interface.
An API for automatic data queries to the fedstat https://www.fedstat.ru, using a small set of functions with a common interface.
Maintainer: Denis Krylov deniskrylovvit@gmail.com
Authors:
Denis Krylov deniskrylovvit@gmail.com
Dmitry Kibalnikov d.kibalnikov@gmail.com
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.