| fedstat_indicators_names_database | R Documentation |
Allows researchers to search for interesting indicators more easily.
The database can be refreshed by the user via fedstat_indicator_info().
fedstat_indicators_names_database
A data frame with the following variables:
the name of the department from which the data comes
thematic grouping of the indicator
indicator id (used in URL and API calls)
indicator name/title
boolean, TRUE if indicator is hidden on the website
The version shipped with the package was last refreshed on 2026-09-04.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.